@@ -5,7 +5,7 @@
 #
 #    Copyright (C) 2004  Richard Jones  <richard followed by funny at sign then jones then a dot then name>
 #
-#    GmailFS - Gmail Filesystem Version 0.6
+#    GmailFS - Gmail Filesystem Version 0.7.2
 #    This program can be distributed under the terms of the GNU GPL.
 #    See the file COPYING.
 #
@@ -165,8 +165,8 @@ def fixQuotedPrintable(body):
     fixed = body
     if re.search("Content-Transfer-Encoding: quoted",body):
         fixed = quopri.decodestring(body)
-    return fixed
-
+    # Map unicode     
+    return fixed.replace('\u003d','=')
 
 def _getMessagesByQuery(ga,queryString):
     tries = 0
@@ -213,6 +213,11 @@ def _pathSeparatorDecode(path):
     s2 = re.sub("__mi__","-",path)
     return re.sub("__pl__","+",path)
 
+
+def _logException(msg):
+    traceback.print_exc(file=sys.stderr)
+    log.exception(msg)
+
 #@+node:class GmailInode
 class GmailInode:
 
@@ -237,15 +242,14 @@ class GmailInode:
             self.blocksize = DefaultBlockSize
             self.ga = ga
             self.msg = msg
-            m = re.match(VersionTag+'=(.*) '+RefInodeTag+'=(.*) '+FsNameTag+'='+MagicStartDelim+'(.*)'+MagicEndDelim,msg.subject)
+            m = re.match(VersionTag+'=(.*) '+RefInodeTag+'=(.*) '+FsNameTag+'='+MagicStartDelim+'(.*)'+MagicEndDelim,msg.subject.replace('\u003d','='))
             matchInode = m.group(2)
 
             log.debug("trying to get inode with:"+matchInode+" from subject:"+msg.subject)
             self.inode_msg = self.getinodeMsg(matchInode)
             self.setInode()
         except:
-            traceback.print_exc(file=sys.stdout)
-            log.error("got exception when getmessages")
+            _logException("got exception when getmessages")
     #@-node:__init__
 
     #@+node:getinodeMsg
@@ -305,7 +309,7 @@ class GmailInode:
         """
         
         try:
-            subject = self.inode_msg.subject
+            subject = self.inode_msg.subject.replace('\u003d','=')
             body = self.inode_msg.source
 	    body = fixQuotedPrintable(body)
             log.debug("setting inode from subject:"+subject)
@@ -318,13 +322,14 @@ class GmailInode:
             self.nlink = int(m.group(4))
             #quotedEquals = "=(?:3D)?(.*)"
             quotedEquals = "=(.*)"
-            m = re.search(ModeTag+quotedEquals+' '+UidTag+quotedEquals+' '+
-  			  GidTag+quotedEquals+' '+
-                          SizeTag+quotedEquals+' '+
-			  AtimeTag+quotedEquals+' '+
-			  MtimeTag+quotedEquals+' '+
-                          CtimeTag+quotedEquals+' '+
-			  BlockSizeTag+quotedEquals, body)
+            m = re.search(re.compile(
+	                  ModeTag+quotedEquals+' ?'+UidTag+quotedEquals+' ?'+
+  			  GidTag+quotedEquals+' ?'+
+                          SizeTag+quotedEquals+' ?'+
+			  AtimeTag+quotedEquals+' ?'+
+			  MtimeTag+quotedEquals+' ?'+
+                          CtimeTag+quotedEquals+' ?'+
+			  BlockSizeTag+quotedEquals, re.DOTALL),body)
 	    self.mode = int(m.group(1))
             self.uid = int(m.group(2))
             self.gid = int(m.group(3))
@@ -334,7 +339,7 @@ class GmailInode:
             self.ctime = int(m.group(7))
             self.blocksize = int(m.group(8))
         except:
-            traceback.print_exc(file=sys.stdout)
+            _logException("got exception when setInode")
             self.ino = None
 
     def unlink(self, path):
@@ -532,20 +537,17 @@ class Gmailfs(Fuse):
 
     
     #@+node:__init__
-    def __init__(self, mountpoint, odata):
+    def __init__(self, mountpoint, **kw):
 
-        # FIXME -- Sebastien Delafond <seb@debian.org>
-        # dirty hack until I change the python-fuse constructor to also
-        # handle its own parameters, and not only the command-line ones. 
-        sys.argv[1] = mountpoint
-        sys.argv[2] = odata
-    
-        Fuse.__init__(self)
+        Fuse.__init__(self, mountpoint, **kw)
     
         log.info("Mountpoint: %s" % self.mountpoint)
-        log.info("Unnamed mount options: %s" % self.optlist)
-        log.info("Named mount options: %s" % self.optdict)
-    
+        log.info("Unnamed mount options: %s" % (self.optlist,))
+	# obfuscate sensitive fields before logging
+	loggableOptdict = self.optdict.copy()
+	loggableOptdict['password'] = '*' * 8
+	log.info("Named mount options: %s" % (loggableOptdict,))
+
         # do stuff to set up your filesystem here, if you want
 
         self.openfiles = {}
@@ -718,8 +720,7 @@ class Gmailfs(Fuse):
                  if len(filename)>0:
                      lst.append(filename)
         except:
-            traceback.print_exc(file=sys.stdout)
-            log.error("got exception when getmessages")
+            _logException("got exception when getmessages")
             lst = None
         return map(lambda x: (x,0), lst)
     #@-node:getdir
@@ -737,7 +738,7 @@ class Gmailfs(Fuse):
             self.inodeCache = {}
             return 0
         except:
-            traceback.print_exc(file=sys.stdout)
+            _logException("Error unlinking file"+path)
             e = OSError("Error unlinking file"+path)
             e.errno = EINVAL
             raise e
@@ -967,7 +968,7 @@ class Gmailfs(Fuse):
             self.openfiles[path] = f
             return 0
         except:
-            traceback.print_exc(file=sys.stdout)
+            _logException("Error opening file"+path)
             e = OSError("Error opening file"+path)
             e.errno = EINVAL
             raise e
@@ -986,7 +987,7 @@ class Gmailfs(Fuse):
 
             return rets
         except:
-            traceback.print_exc(file=sys.stdout)
+            _logException("Error reading file"+path)
             e = OSError("Error reading file"+path)
             e.errno = EINVAL
             raise e
@@ -1003,7 +1004,7 @@ class Gmailfs(Fuse):
             written = f.write(buf,off)
     	    return written
         except:
-            traceback.print_exc(file=sys.stdout)
+            _logException("Error opening file"+path)
             e = OSError("Error opening file"+path)
             e.errno = EINVAL
             raise e
@@ -1085,8 +1086,7 @@ class Gmailfs(Fuse):
             thread._messages = thread._getMessages(thread)
           return thread._messages[len(thread._messages)-1]
       except:
-          traceback.print_exc(file=sys.stdout)
-          log.error("no slash in path:"+path)
+          _logException("no slash in path:"+path)
           return None
 
 
@@ -1126,8 +1126,8 @@ try:
 except:
     pass
 
-def main(mountpoint, odata):
-    server = Gmailfs(mountpoint, odata)
+def main(mountpoint, namedOptions):
+    server = Gmailfs(mountpoint, **namedOptions)
     server.flags = 0
     server.multithreaded = 0;
     server.main()
